import boto3

eks = boto3.client('eks')


class ClusterConfig:
    def __init__(self, cluster_id, desired_size):
        self.cluster_id = cluster_id
        self.desired_size = desired_size


class NodeGroup:
    def __init__(self, nodegroupName, desired_size, max_size):
        self.nodegroupName = nodegroupName
        self.max_size = max_size
        self.desired_size = 0

    def inc(self):
        self.desired_size += 1


class NodeGroupList:
    def __init__(self, config: ClusterConfig):
        self.pos = 0
        self.desired_size = config.desired_size
        self.cluster_name = config.cluster_id
        print('NodeGroupList(' + config.cluster_id + ')')

        # read in the node groups
        ngs = eks.list_nodegroups(clusterName=config.cluster_id)['nodegroups']
        self.nodegroup_count = len(ngs)

        self.nodegroups = []
        for nodegroupName in ngs:
            nodegroup = eks.describe_nodegroup(
                clusterName=config.cluster_id,
                nodegroupName=nodegroupName
            )['nodegroup']

            self.nodegroups.append(NodeGroup(
                nodegroupName,
                config.desired_size,
                nodegroup['scalingConfig']['maxSize']
            ))

        # build up new configurations
        for i in range(int(config.desired_size)):
            self.inc()

    def inc(self):
        self.nodegroups[self.pos].inc()
        self.pos += 1
        self.pos %= self.nodegroup_count

    def update(self):
        for ng in self.nodegroups:
            response = eks.update_nodegroup_config(
                clusterName=self.cluster_name,
                nodegroupName=ng.nodegroupName,
                scalingConfig={
                    'minSize': ng.desired_size,
                    'maxSize': ng.max_size,
                    'desiredSize': ng.desired_size
                }
            )
        return self.nodegroups


def handler(event, context):
    response = eks.list_clusters()

    # Create list of cluster_id's with desired cluster size
    # on automatic startup.
    cluster_list = []
    for cluster_id in response['clusters']:

        tags = eks.describe_cluster(name=cluster_id)['cluster']['tags']
        if 'eks-autostart' in tags:
            config = ClusterConfig(cluster_id, tags['eks-autostart'])
            cluster_list.append(config)

    # Process each cluster
    for c in cluster_list:
        ng_list = NodeGroupList(c)
        ng_list.update()
